/**
   class PMT (executable)

   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA

**/

package de.ims.cl.dv.space.transform;

import java.io.*; 

import de.ims.cl.dv.space.SemanticSpaceArray;
import de.ims.cl.dv.util.DVCommandLineMap;
import de.ims.cl.dv.util.Parameters;

/** <b>executable</b> This class performs a local logged pointwise mutual 
 * information transformation (Evert 2004, Baroni 2010) on a semantic space 
 * constructed by ExtractSpace. It additionally needs the frequency lists 
 * produced by ExtractBasisElements to provide the marginal frequencies.**/

public class LocalLogPMT extends Transformation{

    protected void showHelp() {
	System.err.println("LocalLogPMT is part of the DependencyVectors package.\n");
	System.err.println("");
	System.err.println("PMT performs a local log PMI transformation on a semantic space matrix.");
	System.err.println("PMT takes the target directory as its only argument");
	System.err.println("PMT requires the semantic space file (produced by ExtractSpace),\nas well as the target, basis elements and total frequency files produced by ExtractBasisElements.\n");	    
	System.err.println("The basis elements are read from targetdir/<contextspec>_<pathvalue>.bes");
	System.err.println("The target words are read from targetdir/<contextspec>_<pathvalue>.targets");
	System.err.println("The semantic space is read from targetdir/<contextspec>_<pathvalue>.vectors\n");
	System.err.println("The total frequency is read from targetdir/<contextspec>_<pathvalue>.total\n");
	System.err.println("The transformed space will be written to targetdir/<contextspec>_<pathvalue>.pmi.vectors\n");
	System.err.println("PMT supports the concurrent transformation of multiple spaces for different parametrisations. To use this feature, do not specify the parameter(s) you want to very."); 
	System.err.println("");
	System.err.println("ExtractSpaces supports the following command line parameters:");
	System.err.println("\t--spec <file>:  file containing context specification (cspec file format) [default: all]");
	System.err.println("\t\tCurrently known specs: "+Parameters.prettyPrintSpecs());
	System.err.println("\t--targetdir <file>: directory in which the files live.");
	System.err.println("\t"+Parameters.prettyPrintVals()+": Valid path value functions [default: all]");

	System.err.println(""); 
	System.err.println("Example: java PMT --targetdir targets\n              --plain --spec contextspec_minimal.txt");
	System.exit(0);
    }
    
    /**
     * Constructor.
     * @param clm
     * @throws IOException
     */
    LocalLogPMT(DVCommandLineMap clm) throws IOException {
    	super(clm);
    }
    
    
     /** This function is called when running the program with <i>java
     * PMT /< arguments />. The program relies on receiving the right
     * command line arguments and will exit if they are not
     * supplied. See help output and documentation for details about
     * arguments. </i>
     **/
   
    public static void main(String[] argarray) {
	try {
	    DVCommandLineMap arguments = Transformation.doInitialization(argarray);
	    LocalLogPMT llt = new LocalLogPMT(arguments);
	    llt.transformSpaces(); // transform and write to file	    
	    llt.log.close();
	    
	} catch (IOException e) {
	    System.err.println("[PMT] IO Error: "+e);	    
	}
    }

	@Override
	protected void callTransformation(SemanticSpaceArray s, double totalnumber) {
		s.locallogpmi(totalnumber);
	}
}
